# KMS (Key Management Service)

The KMS module provides secure key management capabilities with support for multiple backends.

```{automodule} pymedsec.kms
   :members:
   :undoc-members:
   :show-inheritance:
```

## KMS Adapters

### Base KMS Adapter

```{automodule} pymedsec.kms.base
   :members:
   :undoc-members:
   :show-inheritance:
```

### Mock KMS Adapter

```{automodule} pymedsec.kms.mock
   :members:
   :undoc-members:
   :show-inheritance:
```

### AWS KMS Adapter

```{automodule} pymedsec.kms.aws_kms
   :members:
   :undoc-members:
   :show-inheritance:
```

### HashiCorp Vault Adapter

```{automodule} pymedsec.kms.vault
   :members:
   :undoc-members:
   :show-inheritance:
```
